@@ -50,7 +50,7 @@ class base_ui():
         """
         self._single_progress = False
         self.ShowWarnings(show_warnings)
-        self.SetProgress(pids, steps, progress, subpids)
+        self.SetProgress(steps, pids, progress, subpids)
     
     
     def Iterate(self, pid=None, subpid=0, **kwargs):
@@ -331,7 +331,7 @@ def get_terminal_width(fd=1):
     return width
 
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __author__ = "Paul Mueller"
 __email__ = "paul.mueller@biotec.tu-dresden.de"
 __license__ = "BSD (3-Clause)"
